pub struct SizeError {
pub kind: SizeErrorKind,
/* private fields */
}Expand description
An error from a CacheTier::len operation.
Use the kind field to distinguish between tiers that don’t
support size reporting (Unsupported) and
actual storage failures (Failed).
Fields
kind: SizeErrorKindThe kind of error that occurred.
Implementations
Sourceimpl SizeError
impl SizeError
Sourcepub fn unsupported() -> Self
pub fn unsupported() -> Self
Creates a new SizeError indicating that the tier does not support size reporting.